class Validator:
    """
    Base validation class.
    """

    def __init__(self, value, argument_name):
        """
        Constructor which initializes the validator with a `value` and `argument_name`
        """
        self.value = value
        self.argument_name = argument_name


    def get_value(self):
        """
        Returns the validator value.
        """
        return self.value


class ArgumentError(Exception):
    """

    """

    def __init__(self, message, value, argument_name):
        """

        """
        super().__init__(message)

        self.value = value
        self.argument_name = argument_name


from __future__ import annotations

from .validator import Validator
from ..errors.argument_error import ArgumentError


class BooleanValidator(Validator):
    """
    Contains all the boolean validation conditions.
    """


    def __init__(self, value: str, argument_name: str):
        """
        Initializes the validator base class with the `value` and `argument_name`.
        """
        super().__init__(value, argument_name)


    def get_value(self) -> str:
        """
        Returns the validator value.
        """
        return super().get_value()


    def is_true(self) -> BooleanValidator:
        """
        Checks whether the given value is `True`. An exception is thrown otherwise.
        """
        if not self.value == True:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should be True but was `{self.value}`',
                self.value,
                self.argument_name
            )

        return self


    def is_false(self) -> BooleanValidator:
        """
        Checks whether the given value is `True`. An exception is thrown otherwise.
        """
        if not self.value == False:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should be False but was `{self.value}`',
                self.value,
                self.argument_name
            )

        return self


from __future__ import annotations

from .validator import Validator
from ..helpers.regex_helper import RegexHelper
from ..errors.argument_error import ArgumentError
from ..errors.argument_null_error import ArgumentNullError
from ..errors.argument_pattern_error import ArgumentPatternError


class StringValidator(Validator):
    """
    Contains all the string validation conditions.
    """


    EMPTY_STRING = ''


    def __init__(self, value: str, argument_name: str):
        """
        Initializes the validator base class with the `value` and `argument_name`.
        """
        super().__init__(value, argument_name)


    def get_value(self) -> str:
        """
        Returns the validator value.
        """
        return super().get_value()


    def is_null(self) -> StringValidator:
        """
        Checks whether the given value is none (null). An exception is thrown otherwise.
        """
        if self.value is not None:
            raise ArgumentNullError(
                f'The argument `{self.argument_name}` should be NULL',
                self.value,
                self.argument_name
            )

        return self


    def is_not_null(self) -> StringValidator:
        """
        Checks whether the given value is NOT none (null). An exception is thrown otherwise.
        """
        if self.value is None:
            raise ArgumentNullError(
                f'The argument `{self.argument_name}` should not be NONE (NULL)',
                self.value,
                self.argument_name
            )

        return self


    def is_null_or_empty(self) -> StringValidator:
        """
        Checks whether the given value is none (null) or an empty string. An exception is thrown otherwise.
        """
        if self.value is not None\
        and self.value != self.EMPTY_STRING:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should be either EMPTY or NULL but was `{self.value}`',
                self.value,
                self.argument_name
            )

        return self


    def is_not_null_or_empty(self) -> StringValidator:
        """
        Checks whether the given value is NOT none (null) or NOT an empty string. An exception is thrown otherwise.
        """
        if self.value is None\
        or self.value == self.EMPTY_STRING:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should not be EMPTY',
                self.value,
                self.argument_name
            )

        return self


    def is_null_or_whitespace(self) -> StringValidator:
        """
        Checks whether the given value is none (null), empty, or consists only of white-space characters.
        An exception is thrown otherwise.
        """
        if self.value is not None\
        and self.value != self.EMPTY_STRING\
        and not str(self.value).isspace():
            raise ArgumentError(
                f'The argument `{self.argument_name}` should be NULL or WHITESPACE but was `{self.value}`',
                self.value,
                self.argument_name
            )

        return self


    def is_not_null_or_whitespace(self) -> StringValidator:
        """
        Checks whether the given value is NOT none (null), NOT empty, and does NOT consist only of white-space characters.
        An exception is thrown otherwise.
        """
        if self.value is None\
        or self.value == self.EMPTY_STRING\
        or str(self.value).isspace():
            raise ArgumentError(
                f'The argument `{self.argument_name}` should not have WHITESPACE',
                self.value,
                self.argument_name
            )

        return self


    def is_shorter_than(self, max_length: int) -> StringValidator:
        """
        Checks whether the given value is shorter in length, than the specified `max_length`.
        An exception is thrown otherwise.
        """
        if len(self.value) >= max_length:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should be shorter than `{max_length}` but is `{len(self.value)}`',
                self.value,
                self.argument_name
            )

        return self


    def is_shorter_or_equal(self, max_length: int) -> StringValidator:
        """
        Checks whether the given value is shorter or equal in length, than the specified `max_length`.
        An exception is thrown otherwise.
        """
        if len(self.value) > max_length:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should be shorter than or equal to `{max_length}` but is `{len(self.value)}`',
                self.value,
                self.argument_name
            )

        return self


    def is_longer_than(self, min_length: int) -> StringValidator:
        """
        Checks whether the given value is longer in length, than the specified `min_length`.
        An exception is thrown otherwise.
        """
        if len(self.value) <= min_length:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should be longer than `{min_length}` but is `{len(self.value)}`',
                self.value,
                self.argument_name
            )

        return self


    def is_longer_or_equal(self, min_length: int) -> StringValidator:
        """
        Checks whether the given value is longer or equal in length, than the specified `min_length`.
        An exception is thrown otherwise.
        """
        if len(self.value) < min_length:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should be longer than or equal to `{min_length}` but is `{len(self.value)}`',
                self.value,
                self.argument_name
            )

        return self


    def has_length(self, length: int) -> StringValidator:
        """
        Checks whether the given value is equal in length to the specified `length`. An exception is thrown otherwise.
        """
        if len(self.value) != length:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should have a length of `{length}` but is `{len(self.value)}`',
                self.value,
                self.argument_name
            )

        return self


    def does_not_have_length(self, length: int) -> StringValidator:
        """
        Checks whether the given value is unequal in length to the specified `length`. An exception is thrown otherwise.
        """
        if len(self.value) == length:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should not have a length of `{length}` but is `{len(self.value)}`',
                self.value,
                self.argument_name
            )

        return self


    def equals(self, value: str) -> StringValidator:
        """
        Checks whether the given value equals the specified `value`. An exception is thrown otherwise.
        """
        if self.value != value:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should equal `{value}` but was actually `{self.value}`',
                self.value,
                self.argument_name
            )

        return self


    def does_not_equal(self, value: str) -> StringValidator:
        """
        Checks whether the given value equals the specified `value`. An exception is thrown otherwise.
        """
        if self.value == value:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should equal `{value}` but was actually `{self.value}`',
                self.value,
                self.argument_name
            )

        return self


    def starts_with(self, value: str) -> StringValidator:
        """
        Checks whether the given value starts with the specified `value`. An exception is thrown otherwise.
        """
        if not str(self.value).startswith(value):
            raise ArgumentError(
                f'The argument `{self.argument_name}` should start with `{value}` but was actually `{self.value}`',
                self.value,
                self.argument_name
            )

        return self


    def does_not_start_with(self, value: str) -> StringValidator:
        """
        Checks whether the given value does not start with the specified `value`. An exception is thrown otherwise.
        """
        if str(self.value).startswith(value):
            raise ArgumentError(
                f'The argument `{self.argument_name}` should not start with `{value}` but was actually `{self.value}`',
                self.value,
                self.argument_name
            )

        return self


    def ends_with(self, value: str) -> StringValidator:
        """
        Checks whether the given value ends with the specified `value`. An exception is thrown otherwise.
        """
        if not str(self.value).endswith(value):
            raise ArgumentError(
                f'The argument `{self.argument_name}` should end with `{value}` but was actually `{self.value}`',
                self.value,
                self.argument_name
            )

        return self


    def does_not_end_with(self, value: str) -> StringValidator:
        """
        Checks whether the given value does not end with the specified `value`. An exception is thrown otherwise.
        """
        if str(self.value).endswith(value):
            raise ArgumentError(
                f'The argument `{self.argument_name}` should not end with `{value}` but was actually `{self.value}`',
                self.value,
                self.argument_name
            )

        return self


    def contains(self, value: str) -> StringValidator:
        """
        Checks whether the given value contains the specified `value`. An exception is thrown otherwise.
        """
        if value not in self.value:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should contain `{value}` but was actually `{self.value}`',
                self.value,
                self.argument_name
            )

        return self


    def does_not_contain(self, value: str) -> StringValidator:
        """
        Checks whether the given value does not contain the specified `value`. An exception is thrown otherwise.
        """
        if value in self.value:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should not contain `{value}` but was actually `{self.value}`',
                self.value,
                self.argument_name
            )

        return self


    def is_regex_match(self, pattern: str) -> StringValidator:
        """
        Checks wether the given value matches the supplied `pattern`. An exception is thrown otherwise.
        """
        if not RegexHelper.is_match(pattern, self.value):
            raise ArgumentPatternError(
                f'The argument `{self.argument_name}` should match the pattern `{pattern}`',
                self.value,
                self.argument_name,
                pattern
            )

        return self


    def is_not_regex_match(self, pattern: str) -> StringValidator:
        """
        Checks whether the given value does not match the supplied `pattern`. An exception is thrown otherwise.
        """
        if RegexHelper.is_match(pattern, self.value):
            raise ArgumentPatternError(
                f'The argument `{self.argument_name}` should match the pattern `{pattern}`',
                self.value,
                self.argument_name,
                pattern
            )

        return self


    def is_in_set(self, set: list) -> StringValidator:
        """
        Checks to see if the given value matches any of the values in the supplied set. An exception is thrown otherwise.
        """
        if not self.value in set:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should match a value specified in the set.',
                self.value,
                self.argument_name
            )

        return self


    def is_in_set_case_insensitive(self, set: list) -> StringValidator:
        """
        Checks to see if the given value matches any of the values in the supplied set.
        Case insensitive.
        An exception is thrown otherwise.
        """
        if not self.value.lower() in (item.lower() for item in set):
            raise ArgumentError(
                f'The argument `{self.argument_name}` should match a value specified in the set.',
                self.value,
                self.argument_name
            )

        return self


    def is_not_in_set(self, set: list) -> StringValidator:
        """
        Checks to see if the given value matches any of the values is not in the supplied set. An exception is thrown otherwise.
        """
        if self.value in set:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should not match a value specified in the set.',
                self.value,
                self.argument_name
            )

        return self


    def is_not_in_set_case_insensitive(self, set: list) -> StringValidator:
        """
        Checks to see if the given value matches any of the values is not in the supplied set.
        Case insensitive.
        An exception is thrown otherwise.
        """
        if self.value.lower() in (item.lower() for item in set):
            raise ArgumentError(
                f'The argument `{self.argument_name}` should not match a value specified in the set.',
                self.value,
                self.argument_name
            )

        return self


from .argument_error import ArgumentError

class ArgumentOutOfRangeError(ArgumentError):
    """

    """


    def __init__(
        self,
        message: str,
        value: int,
        argument_name: str,
        equal_to: int = None,
        min_value: int = None,
        max_value: int = None
    ):
        """

        """
        super().__init__(
            message,
            value,
            argument_name
        )
        self.equal_to = equal_to
        self.min_value = min_value
        self.max_value = max_value


from __future__ import annotations

from typing import TypeVar
from .validator import Validator
from ..errors.argument_error import ArgumentError
from ..errors.argument_null_error import ArgumentNullError
from ..errors.argument_out_of_range_error import ArgumentOutOfRangeError


number = TypeVar('number', int, float)


class NumberValidator(Validator):
    """
    Contains all the number (int and float) validation conditions.
    """


    def __init__(self, value: str, argument_name: str):
        """
        Initializes the validator base class with the `value` and `argument_name`.
        """
        super().__init__(value, argument_name)


    def get_value(self) -> str:
        """
        Returns the validator value.
        """
        return super().get_value()


    def is_in_range(self, min_value: number, max_value: number) -> NumberValidator:
        """
        Checks whether the given value is between `min_value` and `max_value` (including those values).
        An exception is thrown otherwise.
        """
        if self.value < min_value or self.value > max_value:
            raise ArgumentOutOfRangeError(
                f'The argument `{self.argument_name}` is out of the range `{min_value}-{max_value}`, was `{self.value}`',
                self.value,
                self.argument_name,
                min_value,
                max_value
            )

        return self


    def is_not_in_range(self, min_value: number, max_value: number) -> NumberValidator:
        """
        Checks whether the given value is not between `min_value` and `max_value` (including those values).
        An exception is thrown otherwise.
        """
        if self.value >= min_value and self.value <= max_value:
            raise ArgumentOutOfRangeError(
                f'The argument `{self.argument_name}` is not out of the range `{min_value}-{max_value}`, was `{self.value}`',
                self.value,
                self.argument_name,
                min_value,
                max_value
            )

        return self


    def is_greater_than(self, min_value: number) -> NumberValidator:
        """
        Checks whether the given value is greater than the specified `min_value`.
        An exception is thrown otherwise.
        """
        if self.value <= min_value:
            raise ArgumentOutOfRangeError(
                f'The argument `{self.argument_name}` should be greater than `{min_value}`, but was `{self.value}`',
                self.value,
                self.argument_name,
                min_value=min_value
            )

        return self


    def is_greater_or_equal(self, min_value: number) -> NumberValidator:
        """
        Checks whether the given value is greater or equal to the specified `min_value`.
        An exception is thrown otherwise.
        """
        if self.value < min_value:
            raise ArgumentOutOfRangeError(
                f'The argument `{self.argument_name}` should be greater or equal to `{min_value}`, but was `{self.value}`',
                self.value,
                self.argument_name,
                min_value=min_value
            )

        return self


    def is_less_than(self, max_value: number) -> NumberValidator:
        """
        Checks whether the given value is less than the specified `max_value`.
        An exception is thrown otherwise.
        """
        if self.value >= max_value:
            raise ArgumentOutOfRangeError(
                f'The argument `{self.argument_name}` should be less than `{max_value}`, but was `{self.value}`',
                self.value,
                self.argument_name,
                max_value=max_value
            )

        return self


    def is_less_or_equal(self, max_value: number) -> NumberValidator:
        """
        Checks whether the given value is less or equal to the specified `max_value`.
        An exception is thrown otherwise.
        """
        if self.value > max_value:
            raise ArgumentOutOfRangeError(
                f'The argument `{self.argument_name}` should be less or equal to `{max_value}`, but was `{self.value}`',
                self.value,
                self.argument_name,
                max_value=max_value
            )

        return self


    def is_equal_to(self, value: number) -> NumberValidator:
        """
        Checks whether the given value is equal to the specified `value`.
        An exception is thrown otherwise.
        """
        if self.value != value:
            raise ArgumentOutOfRangeError(
                f'The argument `{self.argument_name}` should be equal to `{value}`, but was `{self.value}`',
                self.value,
                self.argument_name,
                equal_to=value
            )

        return self


    def is_not_equal_to(self, value: number) -> NumberValidator:
        """
        Checks whether the given value is not equal to the specified `value`.
        An exception is thrown otherwise.
        """
        if self.value == value:
            raise ArgumentOutOfRangeError(
                f'The argument `{self.argument_name}` should not be equal to `{value}`, but was `{self.value}`',
                self.value,
                self.argument_name,
                equal_to=value
            )

        return self


    def is_positive(self) -> NumberValidator:
        """
        Checks to see whether the given value is positive or not.
        An exception is thrown otherwise.
        """
        if self.value < 0:
            raise ArgumentOutOfRangeError(
                f'The argument `{self.argument_name}` should be positive (or 0), but was `{self.value}`',
                self.value,
                self.argument_name
            )

        return self


    def is_negative(self) -> NumberValidator:
        """
        Checks to see whether the given value is positive or not.
        An exception is thrown otherwise.
        """
        if self.value >= 0:
            raise ArgumentOutOfRangeError(
                f'The argument `{self.argument_name}` should be negative, but was `{self.value}`',
                self.value,
                self.argument_name
            )

        return self


from typing import TypeVar
from .argument_error import ArgumentError


object_class = TypeVar('object_class', object, type)


class ArgumentNullError(ArgumentError):
    """

    """


    def __init__(
        self,
        message: str,
        value: object_class,
        argument_name: str
    ):
        """

        """
        super().__init__(
            message,
            value,
            argument_name
        )


from .argument_error import ArgumentError

class ArgumentPatternError(ArgumentError):
    """

    """


    def __init__(
        self,
        message: str,
        value: str,
        argument_name: str,
        pattern: str
    ):
        """

        """
        super().__init__(
            message,
            value,
            argument_name
        )
        self.pattern = pattern


import re

class RegexHelper:
    """
    Defines regex helper methods.
    """

    @staticmethod
    def is_match(pattern: str, string: str) -> bool:
        """
        Returns `True` or `False` if a regex match has been found in the string.
        """
        if re.match(pattern, string) is not None:
            return True
        else:
            return False


from typing import TypeVar, Generic
from .validators.validator import Validator
from .validators.string_validator import StringValidator
from .validators.object_validator import ObjectValidator
from .validators.number_validator import NumberValidator
from .validators.boolean_validator import BooleanValidator


number = TypeVar('number', int, float)


class Condition:
    """
    Base condition class to create the validator which corresponds to the value type.
    """


    @staticmethod
    def requires_obj(value: object, argument_name: str) -> ObjectValidator:
        """
        Initializes the conditions framework using the `number (float, int)` validator.
        """
        return ObjectValidator(value, argument_name)


    @staticmethod
    def requires_num(value: number, argument_name: str) -> NumberValidator:
        """
        Initializes the conditions framework using the `number (float, int)` validator.
        """
        return NumberValidator(value, argument_name)


    @staticmethod
    def requires_bool(value: bool, argument_name: str) -> BooleanValidator:
        """
        Initializes the conditions framework using the `boolean` validator.
        """
        return BooleanValidator(value, argument_name)


    @staticmethod
    def requires_str(value: object, argument_name: str) -> StringValidator:
        """
        Initializes the conditions framework using the `string` validator.
        """
        return StringValidator(value, argument_name)


from __future__ import annotations

from inspect import isclass
from typing import Type, Union
from .validator import Validator
from ..errors.argument_error import ArgumentError
from ..errors.argument_null_error import ArgumentNullError


class ObjectValidator(Validator):
    """
    Contains all the object validation conditions.
    """


    def __init__(self, value: object, argument_name: str):
        """
        Initializes the validator base class with the `value` and `argument_name`.
        """
        super().__init__(value, argument_name)


    def get_value(self) -> str:
        """
        Returns the validator value.
        """
        return super().get_value()


    def is_of_type_name(self, type: object) -> ObjectValidator:
        """
        Checks whether the Type of the given value is of `type` by comparing the `__name__` attribute.
        An exception is thrown otherwise.
        """
        if isclass(type):
            raise TypeError(
                f'The argument `{self.argument_name}` should be an initialized object rather than a type, did you mean to use `is_of_type()`?.'
            )

        if not self.value.__class__.__name__ == type.__class__.__name__:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should be of type `{type.__class__.__name__}` but was `{self.value.__class__.__name__}`',
                self.value,
                self.argument_name
            )

        return self


    def is_not_of_type_name(self, type: object) -> ObjectValidator:
        """
        Checks whether the Type of the given value is not of `type` by comparing the `__name__` attribute.
        An exception is thrown otherwise.
        """
        if isclass(type):
            raise TypeError(
                f'The argument `{self.argument_name}` should be an initialized object rather than a type, did you mean to use `is_not_of_type()`?.'
            )

        if self.value.__class__.__name__ == type.__class__.__name__:
            raise ArgumentError(
                f'The argument `{self.argument_name}` should not be of type `{type.__class__.__name__}` but was `{self.value.__class__.__name__}`',
                self.value,
                self.argument_name
            )

        return self


    def is_of_type(self, type: Type) -> ObjectValidator:
        """
        Checks whether the Type of the given value is of `type` by comparing the types using `isinstance()`.
        An exception is thrown otherwise.
        """
        if not isclass(type):
            raise TypeError(
                f'The argument `{self.argument_name}` should be an type rather than an initialized object, did you mean to use `is_of_type_name()`?.'
            )

        if not isinstance(self.value, type):
            raise ArgumentError(
                f'The argument `{self.argument_name}` should be of type `{type.__name__}` but was `{self.value.__class__.__name__}`',
                self.value,
                self.argument_name
            )

        return self


    def is_not_of_type(self, type: Type) -> ObjectValidator:
        """
        Checks whether the Type of the given value is of `type` by comparing the types using `isinstance()`.
        An exception is thrown otherwise.
        """
        if not isclass(type):
            raise TypeError(
                f'The argument `{self.argument_name}` should be an type rather than an initialized object, did you mean to use `is_not_of_type_name()`?.'
            )

        if isinstance(self.value, type):
            raise ArgumentError(
                f'The argument `{self.argument_name}` should not be of type `{type.__name__}` but was `{self.value.__class__.__name__}`',
                self.value,
                self.argument_name
            )

        return self


    def is_null(self) -> ObjectValidator:
        """
        Checks whether the given value is None (Null). An exception is thrown otherwise.
        """
        if not self.value is None:
            raise ArgumentNullError(
                f'The argument `{self.argument_name}` should be NONE (NULL)',
                self.value,
                self.argument_name
            )

        return self


    def is_not_null(self) -> ObjectValidator:
        """
        Checks whether the given value is None (Null). An exception is thrown otherwise.
        """
        if self.value is None:
            raise ArgumentNullError(
                f'The argument `{self.argument_name}` should not be NONE (NULL)',
                self.value,
                self.argument_name
            )

        return self


    def is_equal_to(self, value: object) -> ObjectValidator:
        """
        Checks whether the given value is equal to the object specified in `value` by comparing the internal dictionaries.
        An exception is thrown otherwise.
        """
        if self.value.__dict__ != value.__dict__:
            raise ArgumentError(
                f'The argument `{self.value.__class__.__name__}` should be equal to `{value.__class__.__name__}`',
                self.value,
                self.argument_name
            )

        return self


    def is_not_equal_to(self, value: object) -> ObjectValidator:
        """
        Checks whether the given value is not equal to the object specified in `value` by comparing the internal dictionaries.
        An exception is thrown otherwise.
        """
        if self.value.__dict__ == value.__dict__:
            raise ArgumentError(
                f'The argument `{self.value.__class__.__name__}` should be equal to `{value.__class__.__name__}`',
                self.value,
                self.argument_name
            )

        return self


    def is_equal_to_using_eq(self, value: object) -> ObjectValidator:
        """
        Checks whether the given value is equal to the object specified in `value` by using the `__eq__()` function in object.
        An exception is thrown otherwise.
        """
        if self.value != value:
            raise ArgumentError(
                f'The argument `{self.value.__class__.__name__}` should be equal to `{value.__class__.__name__}`',
                self.value,
                self.argument_name
            )

        return self


    def is_not_equal_to_using_ne(self, value: object) -> ObjectValidator:
        """
        Checks whether the given value is not equal to the object specified in `value` using the `__ne__()` function in the object.
        An exception is thrown otherwise.
        """
        if self.value == value:
            raise ArgumentError(
                f'The argument `{self.value.__class__.__name__}` should be equal to `{value.__class__.__name__}`',
                self.value,
                self.argument_name
            )

        return self


from setuptools import setup

setup(
    name='conditions_py',
    version='0.1.5',
    packages=[
        'conditions_py',
        'conditions_py.errors',
        'conditions_py.helpers',
        'conditions_py.validators',
    ],
    package_dir={
        'conditions_py': 'src'
    },
    url='https://github.com/GenesisCoast/conditions-py',
    license='MIT',
    author='Harry Sanderson',
    author_email='harrysanderson@hotmail.co.uk',
    description='conditions-py is a library that helps write pre- and postcondition validations in a fluent manner, helping improve the readability and reliability of code.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: Implementation :: CPython',
        # 'Topic :: Software Development :: Libaries :: Application Frameworks',
        # 'Topic :: Software Development :: Libaries :: Python Modules',
        # 'Topic :: Software Development :: Quality Assurance',
        # 'Topic :: Utilities'
    ]
)


from .boolean_validator import BooleanValidator
from .number_validator import NumberValidator
from .object_validator import ObjectValidator
from .string_validator import StringValidator
from .validator import Validator


from .argument_error import ArgumentError
from .argument_null_error import ArgumentNullError
from .argument_out_of_range_error import ArgumentOutOfRangeError
from .argument_pattern_error import ArgumentPatternError